/* gnubiff -- a mail notification program
 * Copyright (C) 2000-2003 Nicolas Rougier
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this software; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#include <sstream>
#include <cstdio>
#include <string>
#include <glib.h>
#include "AppletGTK.h"
#include "Mailbox.h"
#include "Popup.h"


// ===================================================================
// = Static attributes ===============================================
// ===================================================================


// ===================================================================
// = Callbacks "C" binding ===========================================
// ===================================================================
extern "C" {
  //! C binding
  gboolean APPLET_GTK_on_button_press (GtkWidget *widget, GdkEventButton *event, gpointer data)
  {return ((AppletGTK *) data)->on_button_press (event);}
}


// ===================================================================
// = AppletGTK =======================================================
// ===================================================================
AppletGTK::AppletGTK (Biff *owner, string xmlFilename) : Applet (owner, xmlFilename) {
}


// ===================================================================
// = ~AppletGTK ======================================================
// ===================================================================
AppletGTK::~AppletGTK (void) {
}


// ===================================================================
// = update ==========================================================
/**
   Update applet (title, image, labels)
 */
// ===================================================================
void AppletGTK::update (void) {
  string text;

  text = "<span font_desc=\"";
  text += _owner->_biff_body_font;
  text += "\">";

  if (_owner->mailbox()->status() == MAILBOX_UNITIALIZED)
    text +=  "<span color=\"yellow\">--</span>";
  else if (_owner->mailbox()->status() == MAILBOX_ERROR)
    text +=  "<span color=\"red\">!!</span>";
  else {
    text += "<span color=\"";
    text += _owner->_biff_body_color;
    text += "\"><b>";
    stringstream unreads;
    unreads << _owner->mailbox()->unreads();
    if (_owner->mailbox()->unreads() < _owner->_max_header_display)
      text += unreads.str();
    else
      text += "++";
    text += "</b></span>";
  }
  text += "</span>";

  GdkPixbufAnimation *gdkpix;
  if (_owner->mailbox()->unreads() > 0)
    gdkpix = gtk_image_get_animation (GTK_IMAGE(_owner->setup()->get("mail_image_image")));
  else
    gdkpix = gtk_image_get_animation (GTK_IMAGE(_owner->setup()->get("no_mail_image_image")));


  gtk_label_set_markup (GTK_LABEL(get ("unread")), text.c_str());

  if (_owner->_display_title) {
    text = "<span font_desc=\"";
    text += _owner->_biff_title_font;
    text += "\" color=\"";
    text += _owner->_biff_title_color;
    text += "\">";
    text += _owner->_title;
    text += "</span>";
    gchar *buffer = g_locale_to_utf8 (text.c_str(),-1,0,0,0);
    gtk_label_set_markup (GTK_LABEL(get ("title")), buffer);
    g_free (buffer);
    gtk_widget_show (get ("title"));
  }
  else
    gtk_widget_hide (get ("title"));


  gtk_image_set_from_animation (GTK_IMAGE (get("image")), gdkpix);

  // Now we update widgets relative to image size
  guint width = gdk_pixbuf_animation_get_width (gdkpix);
  guint height = gdk_pixbuf_animation_get_height (gdkpix);
  gtk_widget_set_size_request (get("fixed"), width, height);
  gtk_widget_set_size_request (get("image"), width, height);
  gtk_widget_set_size_request (get("title"), width, -1);
  gtk_widget_set_size_request (get("unread"), width, -1);

  GtkRequisition req;
  gtk_widget_size_request (get("unread"), &req);
  gtk_fixed_move (GTK_FIXED(get("fixed")), get("unread"), 0, height-req.height);

  // Update window manager decorations
  gtk_window_set_decorated (GTK_WINDOW(get("dialog")), _owner->_biff_decorated);

  show();
}

// ===================================================================
// = show ============================================================
/**
   Make the window visible and position it.
   @param name This is the name of the widget, not used here
*/
// ===================================================================
void AppletGTK::show (string name) {
  string geometry  = "";

  if (_owner->_biff_x_sign == SIGN_PLUS)
    geometry += "+";
  else
    geometry += "-";
  stringstream x;
  x << _owner->_biff_x;
  geometry += x.str();

  if (_owner->_biff_y_sign == SIGN_PLUS)
    geometry += "+";
  else
    geometry += "-";
  stringstream y;
  y << _owner->_biff_y;
  geometry += y.str();

  if ((!_owner->_hide_nomail) || (_owner->mailbox()->status() == MAILBOX_OLD) || (_owner->mailbox()->status() == MAILBOX_NEW)) {
    gtk_widget_show (get("dialog"));
    if (!_owner->_biff_no_geometry)
      gtk_window_parse_geometry (GTK_WINDOW(get("dialog")), geometry.c_str());
  }
  else
    gtk_widget_hide (get("dialog"));
}


// ===================================================================
// = hide ============================================================
/**
   Make the window invisible
   @param name This is the name of the widget, not used here
*/
// ===================================================================
void AppletGTK::hide (string name) {
  gtk_widget_show (get("dialog"));
}


// ===================================================================
// = on_button_press =================================================
/**
   Callback on button press event: button1 forces mailcheck, button2
   opens mail client, button3 opens configuration dialog
   @param event is the button event
   @return true
*/
// ===================================================================
gboolean AppletGTK::on_button_press (GdkEventButton *event) {
  if (event->button == 1) {
    _owner->applet()->stop();
    _owner->mailbox()->update();
    _owner->mailbox()->fetch();
    update();
    if ((_owner->mailbox()->status() == MAILBOX_NEW) || (_owner->mailbox()->status() == MAILBOX_OLD)) {
      _owner->popup()->update();
      _owner->popup()->show();
    }
    else
      _owner->applet()->start();
  }	
  else if (event->button == 2) {
    string command = _owner->_mail_app + " &";
    system (command.c_str());
  }
  else if (event->button == 3) {
    _owner->applet()->stop();
    _owner->popup()->hide();
    _owner->setup()->show();
  }

  return true;
}
