/* gnubiff -- a mail notification program
 * Copyright (C) 2000-2003 Nicolas Rougier
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this software; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

// ===================================================================
/**
   @class Popup
   @brief Interface class for popup window

   This class is for the popup window displayed when there are new
   mails. It handles utf8, printed-quotables and base64 conversions.
*/
// ===================================================================

#ifndef _POPUP_H
#define _POPUP_H

#ifdef HAVE_CONFIG_H
#   include "../config/config.h"
#endif
#include "GUI.h"
#include "Biff.h"


// ===================================================================
// - Constant definitions --------------------------------------------
// ===================================================================


using namespace std;
class Popup : public GUI {
  // ===================================================================
  // - Public methods --------------------------------------------------
  // ===================================================================
public:
  //! @name Base functions
  Popup (class Biff *owner, string xmlFilename);
  virtual ~Popup (void);
  //@}

  //! @name Object manipulations
  virtual gint create (void);
  void update (void);
  void show (string name = "dialog");
  // @}


  //! @name Callbacks
  gboolean on_delete (GtkWidget *widget, GdkEvent *event);
  gboolean on_popdown (void);
  gboolean on_button_press (GdkEventButton *event);
  gboolean on_button_release (GdkEventButton *event);
  void on_enter (GdkEventCrossing *event);
  void on_leave (GdkEventCrossing *event);
  void on_select (GtkTreeSelection *selection);
  // @}


  // ===================================================================
  // - Public attributes -----------------------------------------------
  // ===================================================================
public:



  // ===================================================================
  // - Protected methods -----------------------------------------------
  // ===================================================================
protected:

  // ===================================================================
  // - Protected attributes --------------------------------------------
  // ===================================================================
protected:
  class Biff *		_owner;		/*!< \brief Owner of this interface	*/


  // ===================================================================
  // - Private methods -------------------------------------------------
  // ===================================================================
 private:
  gchar *parse_header (string text);
  int decode_quoted (const gchar *buftodec, gchar *decbuf);
  int decode_base64 (const gchar *buftodec, gchar *decbuf);
  gchar *convert (string text, string charset);



  // ===================================================================
  // - Private attributes ----------------------------------------------
  // ===================================================================
private:
  gint			_poptag;		/*!< \brief Tag for pop timer */
  header *		_selected_header;	/*!< \brief  Current selected header */
  GtkTreeSelection *	_tree_selection;	/*!< \brief Current tree selection */
  gboolean		_consulting;		/*!< \brief Tag to know if we're consulting a mail */
  gint			_x;			/*!< \brief Last mouse x position known */
  gint			_y;			/*!< \brief Last mouse y position known */
};

#endif /* _POPUP_H */
