/* gnubiff -- a mail notification program
 * Copyright (C) 2000-2003 Nicolas Rougier
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this software; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

// ===================================================================
/**
   @class Setup
   @brief Interface class for Biff class 

   This interface allows the user to manipulate settings through a
   notebook and several pages organized by "theme".  Changes are not
   "live" handled since it would require one callback function by
   parameter. Instead we define two functions, one for mapping owner
   features (a Biff object) to GUI and the other for mapping GUI
   values to the owner object.
*/
// ===================================================================

#ifndef _SETUP_H
#define _SETUP_H

#ifdef HAVE_CONFIG_H
#   include "../config/config.h"
#endif
#include "GUI.h"


// ===================================================================
// - Constant definitions --------------------------------------------
// ===================================================================


using namespace std;
class Setup : public GUI {
  // ===================================================================
  // - Public methods --------------------------------------------------
  // ===================================================================
public:
  //! @name Base functions
  Setup (class Biff *owner, string xmlFilename);
  ~Setup (void);
  //@}

  //! @name Object manipulations
  gint create (void);
  void update (void);
  void updateOwner (void);
  // @}

  //! @name Callbacks ==================================================
  gboolean on_delete (GtkWidget *widget,  GdkEvent *event);
  void on_cancel (void);
  void on_save (void);
  void on_quit (void);
  void on_suspend (void);
  void on_tree_select (GtkTreeSelection *selection);
  void on_protocol (void);
  void on_sound (void);
  void on_misc_change (void);
  void on_browse_address (void);
  void on_browse_certificate (void);
  void on_browse_sound (void);
  void on_play_sound (void);
  void on_browse_mail_app (void);
  void on_browse_mail_image (void);
  void on_browse_nomail_image (void);
  void on_browse_font (string name);
  void on_browse_color (string name);
  // @}


  // ===================================================================
  // - Public attributes -----------------------------------------------
  // ===================================================================
public:



  // ===================================================================
  // - Protected methods -----------------------------------------------
  // ===================================================================
protected:

  // ===================================================================
  // - Protected attributes --------------------------------------------
  // ===================================================================
protected:



  // ===================================================================
  // - Private methods -------------------------------------------------
  // ===================================================================
private:
  void addTreeBranch (GtkTreeStore *tree,
		      gchar *notebook_abel,
		      const gchar *icon,
		      gchar *tree_label,
		      GtkTreeIter *parent,
		      GtkTreeIter *iter,
		      gint page_index);


  // ===================================================================
  // - Private attributes ----------------------------------------------
  // ===================================================================
private:
  class Biff *		_owner;		/*!< \brief Owner of this interface	*/
};

#endif /* _SETUP_H */
